<?php
/*
 * PSX is an open source PHP framework to develop RESTful APIs.
 * For the current version and information visit <https://phpsx.org>
 *
 * Copyright 2010-2023 Christoph Kappestein <christoph.kappestein@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace PSX\Http\Exception;

/**
 * The HyperText Transfer Protocol (HTTP) 401 Unauthorized response status code indicates that the client request has
 * not been completed because it lacks valid authentication credentials for the requested resource.
 *
 * This status code is sent with an HTTP WWW-Authenticate response header that contains information on how the client
 * can request for the resource again after prompting the user for authentication credentials.
 *
 * This status code is similar to the 403 Forbidden status code, except that in situations resulting in this status
 * code, user authentication can allow access to the resource.
 *
 * @author  Christoph Kappestein <christoph.kappestein@gmail.com>
 * @license http://www.apache.org/licenses/LICENSE-2.0
 * @link    https://phpsx.org
 */
class UnauthorizedException extends ClientErrorException
{
    protected string $type;
    protected array $parameters;

    public function __construct(string $message, string $type, array $parameters = [], \Throwable $previous = null)
    {
        parent::__construct($message, 401, $previous);

        $this->type       = $type;
        $this->parameters = $parameters;
    }

    public function getType(): string
    {
        return $this->type;
    }

    public function getParameters(): array
    {
        return $this->parameters;
    }
}
